@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -191,7 +191,7 @@ static int json_write(json_object *obj, const char *filename)
 	}
 
 	fprintf(fp, "%s", str);
-	fclose(fp);
+	(void)fclose(fp);
 	json_object_put(obj);
 
 	return 0;
